package com.ebei.screen.common.util;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.ebei.screen.common.constants.EbaSystemConstants;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * EBA大屏工具类
 *
 * @author Levi.u
 * @date 2021/1/13 21:03
 */
@Slf4j
@Component
public class EbaUtils {

    private static Integer SUCCESS_CODE = 200;

    private static MongoTemplate mongoTemplate;

    @Autowired
    public void setMongoTemplate(MongoTemplate mongoTemplate) {
        EbaUtils.mongoTemplate = mongoTemplate;
    }

    /**
     * 判断执行结果是否成功
     *
     * @param result true成功 false失败
     * @return
     */
    public static boolean isSuccess(String result) {
        return SUCCESS_CODE.equals(JSON.parseObject(result).getInteger("code"));
    }

    /**
     * 01、获取token
     *
     * @return
     */
    public static String getTokenInfo() {
        Map tokenMap = mongoTemplate.findById("ebatoken", Map.class, "ebaAuth");
        if (tokenMap != null) {
            String token = (String) tokenMap.get("token");
        }
        String param = JSON.toJSONString(Levi.by("clientId", EbaSystemConstants.cliendId).set("clientSecret", EbaSystemConstants.clientSecret));
        String result = HttpRequest.post(EbaSystemConstants.getTokenInfo)
                .header("content-type", "application/json")
                .body(param)
                .execute().body();
        if (isSuccess(result)) {
            String token = LeviUtils.getJsonFieldOne(result, "data.token", String.class);
            mongoTemplate.insert(Levi.by("_id", "ebatoken").set("token", token).set("expire", LocalDateTime.now()), "ebaAuth");
            return token;
        }
        return null;
    }

    /**
     * 02、获取当前用户名下项目列表
     *
     * @return
     */
    public static void getProjectList() {
        String result = HttpRequest.post(EbaSystemConstants.getProjectList)
                .header("token", getTokenInfo())
                .execute().body();
        if (isSuccess(result)) {
            List<Map> list = LeviUtils.getJsonFieldMany(result, "data.projectList", Map.class);
            mongoTemplate.dropCollection("eba-projectList");
            mongoTemplate.insert(list, "eba-projectList");
        }
    }

    /**
     * 03、根据项目id获取所有device信息
     *
     * @return
     */
    public static void getMobjectList() {
        List<Levi> projectList = mongoTemplate.findAll(Levi.class, "eba-projectList");
        List<Levi<Integer, List>> result = new ArrayList<>();
        if (CollUtil.isNotEmpty(projectList)) {
            projectList.forEach(x -> {
                Integer projectId = (Integer) x.get("projectId");
                String param = JSON.toJSONString(Levi.by("projectId", projectId));
                String str = HttpRequest.post(EbaSystemConstants.getMobjectList)
                        .header("token", getTokenInfo())
                        .body(param)
                        .execute().body();
                if (isSuccess(str)) {
                    result.add(Levi.by(projectId, LeviUtils.getJsonFieldMany(str, "data.mObjectList", Map.class)));
                }
            });
            mongoTemplate.dropCollection("eba-projectMobjectList");
            mongoTemplate.insertAll(result);
        }
    }

    /**
     * 04、根据项目id获取所有iot信息
     *
     * @param projectId 所属项目ID
     * @return
     */
    public static List<Map> getIotList(Long projectId) {
        String param = JSON.toJSONString(Levi.by("projectId", projectId));
        String result = HttpRequest.post(EbaSystemConstants.getIotList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 04、根据项目id获取所有iot信息:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 05、获取所有设备信息(deviceSys)
     *
     * @return
     */
    public static List<Map> getDeviceSystemList() {
        String result = HttpRequest.post(EbaSystemConstants.getDeviceSystemList)
                .header("token", getTokenInfo())
                .execute().body();
        log.info("######### 05、获取所有设备信息(deviceSys):{}", result);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 06、获取所有设备类型信息(deviceType)
     *
     * @return
     */
    public static List<Map> getDeviceTypeList() {
        String result = HttpRequest.post(EbaSystemConstants.getDeviceTypeList)
                .header("token", getTokenInfo())
                .execute().body();
        log.info("######### 06、获取所有设备类型信息(deviceType):{}", result);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 07、获取所有设备参数信息(deviceParam)
     *
     * @return
     */
    public static List<Map> getDeviceParamList() {
        String result = HttpRequest.post(EbaSystemConstants.getDeviceParamList)
                .header("token", getTokenInfo())
                .execute().body();
        log.info("######### 07、获取所有设备参数信息(deviceParam):{}", result);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 08、获取所有设备告警类型信息(alarmType)
     *
     * @return
     */
    public static List<Map> getDeviceAlarmTypeList() {
        String result = HttpRequest.post(EbaSystemConstants.getDeviceAlarmTypeList)
                .header("token", getTokenInfo())
                .execute().body();
        log.info("######### 08、获取所有设备告警类型信息(alarmType):{}", result);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 09、获取所有消防设备类型信息(fireDeviceType)
     *
     * @return
     */
    public static List<Map> getFireDeviceTypeList() {
        String result = HttpRequest.post(EbaSystemConstants.getFireDeviceTypeList)
                .header("token", getTokenInfo())
                .execute().body();
        log.info("######### 09、获取所有消防设备类型信息(fireDeviceType):{}", result);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 10、根据deviceId和deviceParamId获取实时device信息
     *
     * @param deviceParams 监测对象数组
     *                     例如：[{"deviceId":监测对象ID,"deviceParamId":监测对象参数ID}]
     * @return
     */
    public static List<Map> getMobjectRealDataList(List<Map<String, Integer>> deviceParams) {
        String param = JSON.toJSONString(Levi.by("deviceParams", deviceParams));
        String result = HttpRequest.post(EbaSystemConstants.getMobjectRealDataList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 10、根据deviceId和deviceParamId获取实时device信息:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.realtimeDataList", Map.class);
    }

    /**
     * 11、根据projectId获取所有实时device信息
     *
     * @param projectId 所属项目ID
     * @return
     */
    public static List<Map> getMobjectRealDataByProjectIdList(Long projectId) {
        String param = JSON.toJSONString(Levi.by("projectId", projectId));
        String result = HttpRequest.post(EbaSystemConstants.getMobjectRealDataByProjectIdList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 11、根据projectId获取所有实时device信息:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }

    /**
     * 12、根据deviceId和deviceParamId获取某段时间内设备能耗数据
     *
     * @param deviceId          设备编号
     * @param deviceParameterId 设备参数编号
     * @param beginTime         开始时间【最大跨度1个月】
     * @param endTime           结束时间【最大跨度1个月】
     * @return
     */
    public static List<Map> getMobjectEnergyList(Long deviceId, Long deviceParameterId, Long beginTime, Long endTime) {
        String param = JSON.toJSONString(Levi.by("deviceId", deviceId).set("deviceParameterId", deviceParameterId).set("beginTime", beginTime).set("endTime", endTime));
        String result = HttpRequest.post(EbaSystemConstants.getMobjectEnergyList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 12、根据deviceId和deviceParamId获取某段时间内设备能耗数据:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.energyData", Map.class);
    }

    /**
     * 13、根据项目id获取实时未恢复告警
     *
     * @param projectId 所属项目ID
     * @return
     */
    public static List<Map> getMobjectRealTimeAlarmList(Long projectId) {
        String param = JSON.toJSONString(Levi.by("projectId", projectId));
        String result = HttpRequest.post(EbaSystemConstants.getMobjectRealTimeAlarmList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 13、根据项目id获取实时未恢复告警:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.alarmList", Map.class);
    }

    /**
     * 14、根据项目id获取历史已恢复告警
     *
     * @param projectId 所属项目ID
     * @param beginTime 查询开始时间
     * @param endTime   查询结束时间
     * @param pageIndex 当前页码
     * @param pageSize  每页显示条数(不能大于100)
     * @return
     */
    public static List<Map> getMobjectHisAlarmPageList(Long projectId, Long beginTime, Long endTime, Integer pageIndex, Integer pageSize) {
        String param = JSON.toJSONString(Levi.by("projectId", projectId).set("beginTime", beginTime).set("endTime", endTime).set("paging", Levi.by("pageIndex", pageIndex).set("pageSize", pageSize)));
        String result = HttpRequest.post(EbaSystemConstants.getMobjectHisAlarmPageList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 14、根据项目id获取历史已恢复告警:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.hisAlarmList", Map.class);
    }

    /**
     * 15、根据iotId获取摄像头地址
     *
     * @param IotId Iot编码
     * @return
     */
    public static List<Map> getIotVideoUrl(Long IotId) {
        String param = JSON.toJSONString(Levi.by("IotId", IotId));
        String result = HttpRequest.post(EbaSystemConstants.getIotVideoUrl)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 15、根据iotId获取摄像头地址:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.hisAlarmList", Map.class);
    }

    /**
     * 16、根据项目id获取iot实时告警列表
     *
     * @param projectId 所属项目ID
     * @return
     */
    public static List<Map> getIotAlarmRealTimeList(Long projectId) {
        String param = JSON.toJSONString(Levi.by("projectId", projectId));
        String result = HttpRequest.post(EbaSystemConstants.getIotAlarmRealTimeList)
                .header("token", getTokenInfo())
                .body(param)
                .execute().body();
        log.info("######### 16、根据项目id获取iot实时告警列表:{} 参数:{}", result, param);
        return LeviUtils.getJsonFieldMany(result, "data.datas", Map.class);
    }
}
