package com.ebei.screen.controller.video;

import cn.hutool.core.bean.BeanUtil;
import com.ebei.screen.common.response.ResponseBean;
import com.ebei.screen.modules.po.Project;
import com.ebei.screen.service.ProjectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotNull;

/**
 * @author Liu.x
 * @description 视频监控大屏
 */

@Slf4j
@Validated
@RestController
@RequestMapping("/video")
@AllArgsConstructor
@Api(value = "视频监控", tags = "视频监控api")
public class VideoMonitorController {

    @Autowired
    private ProjectService projectService;

    @ApiOperation("保存项目")
    @PostMapping("/saveProject")
    public ResponseBean saveProject(@RequestBody Project project) {
        projectService.saveProject(project);
        return ResponseBean.success();
    }

    @ApiOperation("修改项目")
    @PostMapping("/updateProject")
    public ResponseBean updateProject(@RequestBody Project project) {
        if(BeanUtil.isEmpty(project.getId())) {
            return ResponseBean.fail("id不能为空");
        }
        return projectService.updateProject(project);
    }

    @ApiOperation("分页查询项目")
    @PostMapping("/queryProject/{page}/{pageSize}")
    public ResponseBean queryProjectPage(@PathVariable("page") @NotNull(message = "URL参数：当前页的页码不能为空") Integer page,
                                      @PathVariable("pageSize") @NotNull(message = "URL参数：当前页的页数不能为空") Integer pageSize,
                                      @RequestParam(value = "name",required = false) String name) {

        return projectService.queryProjectPage(page-1,pageSize,name);
    }

}
