package com.ebei.screen.service;

import java.util.List;
import java.util.Map;

/**
 * EBA系统大屏
 *
 * @author Levi.u
 * @date 2021/1/13 14:26
 */
public interface EbaSystemService {

    /**
     * 根据项目id获取所有device信息
     */
    void getMobjectList(Long projectId);

    /**
     * 根据项目id获取所有iot信息
     *
     * @param projectId
     */
    void getIotList(Long projectId);

    /**
     * 获取所有设备信息(deviceSys)
     */
    void getDeviceSystemList();

    /**
     * 获取所有设备类型信息(deviceType)
     */
    void getDeviceTypeList();

    /**
     * 获取所有设备参数信息(deviceParam)
     */
    void getDeviceParamList();

    /**
     * 获取所有设备告警类型信息(alarmType)
     */
    void getDeviceAlarmTypeList();

    /**
     * 获取所有消防设备类型信息(fireDeviceType)
     */
    void getFireDeviceTypeList();

    /**
     * 根据deviceId和deviceParamId获取实时device信息
     *
     * @param deviceParams
     */
    void getMobjectRealDataList(List<Map<String, Integer>> deviceParams);

    /**
     * 根据projectId获取所有实时device信息
     *
     * @param projectId
     */
    void getMobjectRealDataByProjectIdList(Long projectId);

    /**
     * 根据deviceId和deviceParamId获取某段时间内设备能耗数据
     *
     * @param deviceId
     * @param deviceParameterId
     * @param beginTime
     * @param endTime
     */
    void getMobjectEnergyList(Long deviceId, Long deviceParameterId, Long beginTime, Long endTime);

    /**
     * 根据项目id获取实时未恢复告警
     *
     * @param projectId
     */
    void getMobjectRealTimeAlarmList(Long projectId);

    /**
     * 根据项目id获取历史已恢复告警
     */
    void getMobjectHisAlarmPageList(Long projectId, Long beginTime, Long endTime, Integer pageIndex, Integer pageSize);

    /**
     * 根据iotId获取摄像头地址
     *
     * @param IotId
     */
    void getIotVideoUrl(Long IotId);

    /**
     * 根据项目id获取iot实时告警列表
     *
     * @param projectId
     */
    void getIotAlarmRealTimeList(Long projectId);
}
