package com.ebei.screen.service.impl;

import com.ebei.screen.common.util.EbaUtils;
import com.ebei.screen.service.EbaSystemService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * EBA系统大屏
 *
 * @author Levi.u
 * @date 2021/1/13 14:30
 */
@Slf4j
@Service("ebaSystemService")
@Transactional(rollbackFor = {Exception.class})
public class EbaSystemServiceImpl implements EbaSystemService {

    @Autowired
    private MongoTemplate mongoTemplate;

    @Override
    public void getMobjectList(Long projectId) {
//        List<Map> mobjectList = EbaUtils.getMobjectList(projectId);
        mongoTemplate.dropCollection("mobjectList");
        mongoTemplate.insert("mobjectList", "mobjectList");
    }

    @Override
    public void getIotList(Long projectId) {
        List<Map> iotList = EbaUtils.getIotList(projectId);
        mongoTemplate.dropCollection("iotList");
        mongoTemplate.insert(iotList, "iotList");
    }

    @Override
    public void getDeviceSystemList() {
        List<Map> deviceSystemList = EbaUtils.getDeviceSystemList();
        mongoTemplate.dropCollection("deviceSystemList");
        mongoTemplate.insert(deviceSystemList, "deviceSystemList");
    }

    @Override
    public void getDeviceTypeList() {
        List<Map> deviceTypeList = EbaUtils.getDeviceTypeList();
        mongoTemplate.dropCollection("deviceTypeList");
        mongoTemplate.insert(deviceTypeList, "deviceTypeList");
    }

    @Override
    public void getDeviceParamList() {
        List<Map> deviceParamList = EbaUtils.getDeviceParamList();
        mongoTemplate.dropCollection("deviceParamList");
        mongoTemplate.insert(deviceParamList, "deviceParamList");
    }

    @Override
    public void getDeviceAlarmTypeList() {
        List<Map> deviceAlarmTypeList = EbaUtils.getDeviceAlarmTypeList();
        mongoTemplate.dropCollection("deviceAlarmTypeList");
        mongoTemplate.insert(deviceAlarmTypeList, "deviceAlarmTypeList");
    }

    @Override
    public void getFireDeviceTypeList() {
        List<Map> fireDeviceTypeList = EbaUtils.getFireDeviceTypeList();
        mongoTemplate.dropCollection("fireDeviceTypeList");
        mongoTemplate.insert(fireDeviceTypeList, "fireDeviceTypeList");
    }

    @Override
    public void getMobjectRealDataList(List<Map<String, Integer>> deviceParams) {
        List<Map> mobjectRealDataList = EbaUtils.getMobjectRealDataList(deviceParams);
        mongoTemplate.dropCollection("mobjectRealDataList");
        mongoTemplate.insert(mobjectRealDataList, "mobjectRealDataList");
    }

    @Override
    public void getMobjectRealDataByProjectIdList(Long projectId) {
        List<Map> dataByProjectIdList = EbaUtils.getMobjectRealDataByProjectIdList(projectId);
        mongoTemplate.dropCollection("dataByProjectIdList");
        mongoTemplate.insert(dataByProjectIdList, "dataByProjectIdList");
    }

    @Override
    public void getMobjectEnergyList(Long deviceId, Long deviceParameterId, Long beginTime, Long endTime) {
        List<Map> mobjectEnergyList = EbaUtils.getMobjectEnergyList(deviceId, deviceParameterId, beginTime, endTime);
        mongoTemplate.dropCollection("mobjectEnergyList");
        mongoTemplate.insert(mobjectEnergyList, "mobjectEnergyList");
    }

    @Override
    public void getMobjectRealTimeAlarmList(Long projectId) {
        List<Map> mobjectRealTimeAlarmList = EbaUtils.getMobjectRealTimeAlarmList(projectId);
        mongoTemplate.dropCollection("mobjectRealTimeAlarmList");
        mongoTemplate.insert(mobjectRealTimeAlarmList, "mobjectRealTimeAlarmList");
    }

    @Override
    public void getMobjectHisAlarmPageList(Long projectId, Long beginTime, Long endTime, Integer pageIndex, Integer pageSize) {
        List<Map> mobjectHisAlarmPageList = EbaUtils.getMobjectHisAlarmPageList(projectId, beginTime, endTime, pageIndex, pageSize);
        mongoTemplate.dropCollection("mobjectHisAlarmPageList");
        mongoTemplate.insert(mobjectHisAlarmPageList, "mobjectHisAlarmPageList");
    }

    @Override
    public void getIotVideoUrl(Long IotId) {
        List<Map> iotVideoUrl = EbaUtils.getIotVideoUrl(IotId);
        mongoTemplate.dropCollection("iotVideoUrl");
        mongoTemplate.insert(iotVideoUrl, "iotVideoUrl");
    }

    @Override
    public void getIotAlarmRealTimeList(Long projectId) {
        List<Map> iotAlarmRealTimeList = EbaUtils.getIotAlarmRealTimeList(projectId);
        mongoTemplate.dropCollection("iotAlarmRealTimeList");
        mongoTemplate.insert(iotAlarmRealTimeList, "iotAlarmRealTimeList");
    }

}
